## Mohamad Saad, July, 2014
## mhsaad@uw.edu
## 
## University of Washington, Seattle, USA
## Statistical genetics: Prof. Ellen wijsman's Group.
## Reference: Saad M and Wijsman EM, 2014. Combining family- and population-based imputation data for association analysis of rare and common variants in large pedigrees. Genet Epi (in press).

##### DEFINE LIBRARIES
.libPaths("/acct/mhsaad/PROGS/R")
library(kinship) 
library(CompQuadForm) 
##### END LIBRARIES

 ## Read the genotype file
 Data = read.table("DATA", h=TRUE)
 ## Make distinct IDs
 Data[ , "IID"] = paste(Data[ , "FID"]  , Data[ , "IID"]  ,sep=".")
 Data[Data[,"FA"]!=0 , "FA"] = paste(Data[Data[,"FA"]!=0 , "FID"]  , Data[Data[,"FA"]!=0 , "FA"]  ,sep=".")
 Data[Data[,"FA"]!=0 , "MO"] = paste(Data[Data[,"FA"]!=0 , "FID"]  , Data[Data[,"FA"]!=0 , "MO"]  ,sep=".")
 ## Estimate the kinship
 KIN =makekinship(Data$FID , Data$IID , Data$FA, Data$MO)
 IID = Data$IID
 ##

##### User can change the weights for rare and common variants.
wuweights_r <- function(maf) ifelse(maf>0, dbeta(maf,1,25), 0)      ## Weight function for rare variants
wuweights_c <- function(maf) ifelse(maf>0, dbeta(maf,0.5,0.5), 0)   ## Weight function for common variants
#####

### Read the famSKAT-RC function
source("famSKAT-RC.function")
####

P_VALUES =  famSKAT_RC(PHENO=Data[,"Phenotype"],genotypes=as.matrix(Data[,7:ncol(Data)]),binomialimpute=TRUE ,id=IID,fullkins=KIN,maf=0.05, sqrtweights_c=wuweights_c , sqrtweights_r=wuweights_r, phi = c(0,0.2,0.5,0.9))  

P_VALUES

## binomialimpute = TRUE : impute missing genotypes using a binomail distribution : Bin(MAF).
## binomialimpute = FALSE: replace missing genotypes by 0 (which means no rare variants).
## id=IID : that should have the id of genotyped individuals
## fullkins= KIN : that should be the full kinship matrix that contains all pedigree members, even those without genotype data.
## sqrtweights_r & sqrtweights_c : weights for rare and common variants respectively.
## phi: this parameter indicates the proportion of contribution of rare variants. For example, a value of phi=0.5 means that the contribution of rare and common variants to the test is equal. You can vary the phi values as you wish.

